CorruptDataError

Enum CorruptDataError 

pub enum CorruptDataError {
    EmptyArchive,
    InvalidBlockSize,
    TooShort {
        byte_count: usize,
        block_count: usize,
    },
    InvalidChecksum {
        block_index: usize,
    },
    InvalidTypeFlag {
        block_index: usize,
    },
    InvalidPayloadSize {
        block_index: usize,
    },
    PayloadExtendsBeyondArchive {
        block_index: usize,
    },
    MissingTerminator,
}
Describes why archive validation failed.

Variants



EmptyArchive

The archive contains no data.



InvalidBlockSize

The archive length is not a multiple of the 512-byte block size.



TooShort

The archive is shorter than MIN_BLOCK_COUNT blocks.

Fields

byte_count: usize

Total number of bytes in the archive.

block_count: usize

Number of complete 512-byte blocks in the archive.



InvalidChecksum

The header at block_index has an invalid checksum.

Fields

block_index: usize

Index of the invalid header block.



InvalidTypeFlag

The header at block_index has an unsupported type flag.

Fields

block_index: usize

Index of the invalid header block.



InvalidPayloadSize

The payload size in the header at block_index is invalid.

Fields

block_index: usize

Index of the header with the invalid payload size.



PayloadExtendsBeyondArchive

A payload starting at block_index extends past the archive.

Fields

block_index: usize

Index of the header that describes the payload.



MissingTerminator

The archive does not end with two zero blocks.