pub struct TarArchiveRef<'a> { /* private fields */ }
Wrapper type around bytes, which represents a Tar archive. Unlike [TarArchive], this uses only a reference to data.

Implementations

Creates a new archive wrapper type. The provided byte array is interpreted as bytes in Tar archive format.

Iterates over all entries of the Tar archive. Returns items of type ArchiveEntry. See also ArchiveIterator.