Struct tar_no_std::TarArchiveRef
source · [−]pub struct TarArchiveRef<'a> { /* private fields */ }Expand description
Wrapper type around bytes, which represents a Tar archive.
Unlike [TarArchive], this uses only a reference to data.
Implementations
sourceimpl<'a> TarArchiveRef<'a>
impl<'a> TarArchiveRef<'a>
sourcepub fn new(data: &'a [u8]) -> Self
pub fn new(data: &'a [u8]) -> Self
Creates a new archive wrapper type. The provided byte array is interpreted as bytes in Tar archive format.
sourcepub const fn entries(&self) -> ArchiveIterator<'_>ⓘNotable traits for ArchiveIterator<'a>impl<'a> Iterator for ArchiveIterator<'a> type Item = ArchiveEntry<'a>;
pub const fn entries(&self) -> ArchiveIterator<'_>ⓘNotable traits for ArchiveIterator<'a>impl<'a> Iterator for ArchiveIterator<'a> type Item = ArchiveEntry<'a>;
Iterates over all entries of the Tar archive.
Returns items of type ArchiveEntry.
See also ArchiveIterator.